@@ -6,6 +6,7 @@ from toqito.matrix_props.is_symmetric import is_symmetric
 from toqito.matrix_props.is_hermitian import is_hermitian
 from toqito.matrix_props.is_identity import is_identity
 from toqito.matrix_props.is_idempotent import is_idempotent
+from toqito.matrix_props.is_permutation import is_permutation
 from toqito.matrix_props.is_positive_semidefinite import is_positive_semidefinite
 from toqito.matrix_props.is_positive_definite import is_positive_definite
 from toqito.matrix_props.is_density import is_density
@@ -13,3 +14,6 @@ from toqito.matrix_props.is_commuting import is_commuting
 from toqito.matrix_props.is_projection import is_projection
 from toqito.matrix_props.is_unitary import is_unitary
 from toqito.matrix_props.majorizes import majorizes
+from toqito.matrix_props.sk_norm import sk_operator_norm
+from toqito.matrix_props.is_block_positive import is_block_positive
+from toqito.matrix_props.is_orthonormal import is_orthonormal
\ No newline at end of file
