@@ -1,8 +1,10 @@
 """Distance metrics for quantum states."""
 from toqito.state_metrics.trace_norm import trace_norm
 from toqito.state_metrics.hilbert_schmidt import hilbert_schmidt
+from toqito.state_metrics.hilbert_schmidt_inner_product import hilbert_schmidt_inner_product
 from toqito.state_metrics.helstrom_holevo import helstrom_holevo
 from toqito.state_metrics.fidelity import fidelity
 from toqito.state_metrics.sub_fidelity import sub_fidelity
 from toqito.state_metrics.trace_distance import trace_distance
 from toqito.state_metrics.bures_distance import bures_distance
+from toqito.state_metrics.matsumoto_fidelity import matsumoto_fidelity
