@@ -5,6 +5,7 @@ from toqito.state_props.is_mixed import is_mixed
 from toqito.state_props.is_mutually_orthogonal import is_mutually_orthogonal
 from toqito.state_props.is_mutually_unbiased_basis import is_mutually_unbiased_basis
 from toqito.state_props.is_ppt import is_ppt
+from toqito.state_props.is_npt import is_npt
 from toqito.state_props.is_product import is_product
 from toqito.state_props.concurrence import concurrence
 from toqito.state_props.negativity import negativity
@@ -16,3 +17,4 @@ from toqito.state_props.entanglement_of_formation import entanglement_of_formati
 from toqito.state_props.l1_norm_coherence import l1_norm_coherence
 from toqito.state_props.in_separable_ball import in_separable_ball
 from toqito.state_props.has_symmetric_extension import has_symmetric_extension
+from toqito.state_props.sk_vec_norm import sk_vector_norm
