@@ -1,5 +1,5 @@
 """Computes the entanglement of formation of a bipartite quantum state."""
-from typing import List, Union
+from __future__ import annotations
 
 import numpy as np
 import scipy
@@ -8,7 +8,7 @@ from toqito.channels import partial_trace
 from toqito.state_props import concurrence, von_neumann_entropy
 
 
-def entanglement_of_formation(rho: np.ndarray, dim: Union[List[int], int] = None) -> float:
+def entanglement_of_formation(rho: np.ndarray, dim: list[int] | int = None) -> float:
     r"""
     Compute entanglement-of-formation of a bipartite quantum state [WikEOF]_.
 
@@ -74,7 +74,7 @@ def entanglement_of_formation(rho: np.ndarray, dim: Union[List[int], int] = None
 
     if np.prod(dim) != max(dim_x, dim_y):
         raise ValueError(
-            "Invalid dimension: Please provide local dimensions " "that match the size of `rho`."
+            "Invalid dimension: Please provide local dimensions that match the size of `rho`."
         )
 
     # If :code:`rho` is a rank-1 density matrix, turn it into a vector instead
@@ -96,8 +96,8 @@ def entanglement_of_formation(rho: np.ndarray, dim: Union[List[int], int] = None
         if dim_x == 4:
             rho_c = concurrence(rho)
 
-            rho_c1 = (1 + np.sqrt(1 - rho_c ** 2)) / 2
-            rho_c2 = (1 - np.sqrt(1 - rho_c ** 2)) / 2
+            rho_c1 = (1 + np.sqrt(1 - rho_c**2)) / 2
+            rho_c2 = (1 - np.sqrt(1 - rho_c**2)) / 2
 
             rho_c1_log2 = 0 if rho_c1 == 0 else np.log2(rho_c1)
             rho_c2_log2 = 0 if rho_c2 == 0 else np.log2(rho_c2)
@@ -108,4 +108,4 @@ def entanglement_of_formation(rho: np.ndarray, dim: Union[List[int], int] = None
             "the entanglement-of-formation for two-qubit states and pure "
             "states."
         )
-    raise ValueError("Invalid dimension: `rho` must be either a vector or " "square matrix.")
+    raise ValueError("Invalid dimension: `rho` must be either a vector or square matrix.")
