@@ -1,12 +1,12 @@
 """Schmidt rank of state."""
-from typing import List, Union
+from __future__ import annotations
 
 import numpy as np
 
 from toqito.perms import swap
 
 
-def schmidt_rank(rho: np.ndarray, dim: Union[int, List[int], np.ndarray] = None) -> float:
+def schmidt_rank(rho: np.ndarray, dim: int | list[int] | np.ndarray = None) -> float:
     r"""
     Compute the Schmidt rank [WikSR]_.
 
@@ -98,16 +98,16 @@ def schmidt_rank(rho: np.ndarray, dim: Union[int, List[int], np.ndarray] = None)
     return np.linalg.matrix_rank(np.reshape(rho, dim[::-1]))
 
 
-def _operator_schmidt_rank(rho: np.ndarray, dim: Union[int, List[int], np.ndarray] = None) -> float:
+def _operator_schmidt_rank(rho: np.ndarray, dim: int | list[int] | np.ndarray = None) -> float:
     """
     Operator Schmidt rank of variable.
 
-    If the input is provided as a density operator instead of a vector, compute the Schmidt rank.
+    If the input is provided as a density operator instead of a vector, compute
+    the operator Schmidt rank.
     """
     if dim is None:
         dim_x = rho.shape
         sqrt_dim = np.round(np.sqrt(dim_x))
-
         dim = np.array([[sqrt_dim[0], sqrt_dim[0]], [sqrt_dim[1], sqrt_dim[1]]])
 
     if isinstance(dim, list):
